==> billogram-foundation-2.0.1.tgz: package/modules/components/dropdown/DropdownContainer.js <==
import React, { PropTypes } from 'react';
import { connect } from 'react-redux';
import selectn from 'selectn';

import actionName from '../../utils/actionName';

import dropdownCollapse from './redux-actions/dropdownCollapse';
import dropdownChange from './redux-actions/dropdownChange';
import dropdownExpand from './redux-actions/dropdownExpand';
import dropdownHighlightedIndexChange from './redux-actions/dropdownHighlightedIndexChange';


const changeType = actionName('CHANGE');
const collapseType = actionName('COLLAPSE');
const expandType = actionName('EXPAND');
const highlightedIndexChangeType = actionName('HIGHLIGHTED-INDEX-CHANGE');

export {
    changeType,
    collapseType,
    expandType,
    highlightedIndexChangeType
};

export default ({
    Component
} = {}) => {

    const Container = React.createClass({

        displayName: `${Component.displayName}Container`,

        propTypes: {
            actionTypePrefix: PropTypes.string.isRequired,
            path: PropTypes.string.isRequired,
            root: PropTypes.string.isRequired
        },

        render() {
            return (
                <Component { ...this.props } />
            );
        }

    });

    const mapStateToProps = (state, props) => {
        const getProperty = (key) => selectn(`${props.root}.${props.path}.${key}`, state.components);

        return {
            expanded: getProperty('expanded'),
            highlightedIndex: getProperty('highlightedIndex'),
            options: getProperty('options'),
            value: getProperty('value')
        };
    };

    const mapDispatchToProps = (dispatch, props) => {
        const { actionTypePrefix, path, root } = props;
        return {
            onChange: (value) => dispatch(dropdownChange({ path, root, type: changeType(actionTypePrefix), value })),
            onCollapse: () => dispatch(dropdownCollapse({ path, root, type: collapseType(actionTypePrefix) })),
            onExpand: () => dispatch(dropdownExpand({ path, root, type: expandType(actionTypePrefix) })),
            onHighlightedIndexChange: (highlightedIndex) => dispatch(dropdownHighlightedIndexChange({ highlightedIndex, path, root, type: highlightedIndexChangeType(actionTypePrefix) }))
        };
    };

    return connect(mapStateToProps, mapDispatchToProps)(Container);

};

==> billogram-foundation-2.0.2.tgz: package/modules/components/dropdown/DropdownContainer.js <==
import React, { PropTypes } from 'react';
import { connect } from 'react-redux';
import selectn from 'selectn';

import actionName from '../../utils/actionName';

import dropdownCollapse from './redux-actions/dropdownCollapse';
import dropdownChange from './redux-actions/dropdownChange';
import dropdownExpand from './redux-actions/dropdownExpand';
import dropdownHighlightedIndexChange from './redux-actions/dropdownHighlightedIndexChange';


const changeType = actionName('CHANGE');
const collapseType = actionName('COLLAPSE');
const expandType = actionName('EXPAND');
const highlightedIndexChangeType = actionName('HIGHLIGHTED-INDEX-CHANGE');

export {
    changeType,
    collapseType,
    expandType,
    highlightedIndexChangeType
};

export default ({
    Component
} = {}) => {

    const Container = React.createClass({

        displayName: `${Component.displayName}Container`,

        propTypes: {
            path: PropTypes.string.isRequired,
            root: PropTypes.string.isRequired,
            // ---
            actionTypePrefix: PropTypes.string
        },

        render() {
            return (
                <Component { ...this.props } />
            );
        }

    });

    const mapStateToProps = (state, props) => {
        const getProperty = (key) => selectn(`${props.root}.${props.path}.${key}`, state.components);

        return {
            expanded: getProperty('expanded'),
            highlightedIndex: getProperty('highlightedIndex'),
            options: getProperty('options'),
            value: getProperty('value')
        };
    };

    const mapDispatchToProps = (dispatch, props) => {
        const { path, root } = props;
        const actionTypePrefix = props.actionTypePrefix || 'DROPDOWN';

        return {
            onChange: (value) => dispatch(dropdownChange({ path, root, type: changeType(actionTypePrefix), value })),
            onCollapse: () => dispatch(dropdownCollapse({ path, root, type: collapseType(actionTypePrefix) })),
            onExpand: () => dispatch(dropdownExpand({ path, root, type: expandType(actionTypePrefix) })),
            onHighlightedIndexChange: (highlightedIndex) => dispatch(dropdownHighlightedIndexChange({ highlightedIndex, path, root, type: highlightedIndexChangeType(actionTypePrefix) }))
        };
    };

    return connect(mapStateToProps, mapDispatchToProps)(Container);

};
